#
# spec file for package urlscan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           urlscan
Version:        1.0.6
Release:        1.4
Summary:        An other URL extractor/viewer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Browsers
URL:            https://github.com/firecat53/urlscan
Source0:        https://github.com/firecat53/urlscan/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        muttrc
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-base
BuildRequires:  python3-devel
BuildRequires:  python3-hatch_vcs
BuildRequires:  python3-hatchling
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  sed
Requires:       python3-base
Requires:       python3-urwid >= 1.2.1
BuildArch:      noarch
%global myname  %name

%description
The urlscan utility displays URLs found in an email message with
the respective context. Selecting an URL uses the Python webbrowser
module to determine which browser to open. It also supports
quoted-printable and base64 encoding.

%prep
%setup -q
install -m 0644 %{SOURCE1} muttrc

%build
SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
export SETUPTOOLS_SCM_PRETEND_VERSION
%pyproject_wheel

%install
%pyproject_install
%{python_expand mkdir -p %{buildroot}%{_defaultdocdir}/%{$python_prefix}-%{myname}
 chmod 755 %{buildroot}%{$python_sitelib}/%{name}/__main__*
 sed -ri '1 { s@(/usr/bin/)env +@\1@ }' %{buildroot}%{$python_sitelib}/%{name}/__main__*
 %fdupes %{buildroot}%{$python_sitelib}
}
sed -ri '1 { s@(/usr/bin/)env +@\1@;s@(/python3)\.[[:digit:]]+@\1@ }' %{buildroot}%{_bindir}/%{name}
if test -e %{buildroot}%{_datadir}/doc/%{myname}*
then
    rm -f %{buildroot}%{_datadir}/doc/%{myname}*/LICENSE
fi
rm -rf %{buildroot}%{_datadir}/doc/%{name}*

%files
%{_bindir}/%{myname}
%{_mandir}/man1/%{myname}.1%{?ext_man}
%{python_sitelib}/%{myname}
%{python_sitelib}/%{myname}-%{version}*-info
%license LICENSE
%doc README.md muttrc

%changelog
* Mon Nov 25 2024 Dr. Werner Fink <werner@suse.de>
- Update to urlscan 1.0.6
  * Bugfix in GitHub Action
  * Github action update to release to pypi and github on tag push
    and release to testpypi on commit.
  * Keybindings for page up/down
* Wed Aug 28 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.0.3:
  * Feature suggestion: Jump directly to next/previous URL (#151)
  * Add fallback-version to pyproject.toml
  * Fix flake python version
* Wed May  1 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.0.2:
  * Correct escaped pipe character in urlscan.1
  * fix: patch invalid escape sequence in regex argument help text to support py3.12
  * read me update - neomutt term color compatability
  * Fix for newer urwid versions
* Wed Jul 26 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Add man page to package
* Mon Jun 12 2023 Dr. Werner Fink <werner@suse.de>
- Also remove left over curly braces at the end of require lines
* Mon Jun 12 2023 Dr. Werner Fink <werner@suse.de>
- Removed invalid Recommends line
* Mon Jun 12 2023 Dr. Werner Fink <werner@suse.de>
- Reintroduce removing /usr/bin/env from shebang lines as well as
  duplicate files them selfs
* Mon Jun 12 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not package this as multi-python flavors: urlscan is a simple
  leaf application written in python. Its python code is not
  consumed by others.
* Fri Jun  2 2023 Dr. Werner Fink <werner@suse.de>
- Update to urlscan 1.0.0
  * Fix search with -c flag. Fixes #131.
  * Add support for IPv6 URLs. Closes #127
  * Mark items in url queue with a *
  * Add version flag
  * Update to pyproject.toml/hatch for builds
- Switch over to flavoured build
  * Is there any way to have one major package e.g. for repeating
    docs for the various flavoured sub packages?
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.10:
  * Add "*" to allowed URL characters. Fix #125
  * Strip whitespace from URLs. Fixes #124
  * Redo redirection of sterr/stdout. Fix #122
* Thu Aug  4 2022 Dr. Werner Fink <werner@suse.de>
- Do not remove egg info anymore as the pythonm3 interpreter
  does not work anymore without this information (boo#1202137)
* Sun Jan 30 2022 Avinesh Kumar <avinesh.kumar@suse.com>
- update to version 0.9.9:
  * Bugfix in f-string
  * Updated setup.py after tagging previous version
- update in version 0.9.8:
  * Update TLD list
  * Fix #118, crash on navigating to non-existant line
  * Pylint fixes
  * Move to subprocess run instead of call and Popen
  * Switch to f-strings
* Fri Oct  8 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.9.7:
  * User-option -W --whitespace-off: remove blank lines and ellipses
  * Update documentation for feature --whitespace-off
  * Correct regex example in urlscan.1
  * Sort and align docstrings
* Wed May 12 2021 Dirk Müller <dmueller@suse.com>
- update to 0.9.6:
  * Python 3.6+ required
  * Convert to newer email.message.EmailMessage format for processing. Closes #98
  * Hopefully fix #105. Escapes every "&" in the URL
  * Attempt --run-safe implementation
  * Fixes #106
  * Scan a selection of email headers for URLs. Closes #97.
  * Add option for custom regex. Closes #79.
  * Allow $ as an acceptable trailing character
  * Fix urwid reverse error. Thanks to @pavoljuhas. Closes #99
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- Update to version 0.9.5
  * Change shebang to specifically call python3
  * Add --width flag to change displayed width. Closes #92.
  * Update tlds and copyright dates
  * Remove workaround for fixed python webbrowser bug (#94)
  * Add -R option to reverse URL/context output. Closes #90
  * Add --single option to quit after opening/copying first link.
    Closes #95
  * Support wl-clipboard. Resolve #88.
* Fri Mar 13 2020 Dr. Werner Fink <werner@suse.de>
- Update to version 0.9.4
  * Remove Python 2 compatibility
- Update to version 0.9.3
  * Cycle through opening links with webbrowser module, xdg-open or --run argument
  * Add option to copy to primary selection or clipboard. Fix #87
  * Generate new config file using command line switch instead of keybinding
  * Allow remapping a key to open url in addition to space and enter
  * Show help menu with F1 and show dynamic keybindings
  * Allow editing key bindings in config.json. Fix #72.
- Set python flavour spec file macro to get the rpm pythin macros defined
- Remove egg information tree as we require python3-urwid
* Thu Feb  7 2019 Dr. Werner Fink <werner@suse.de>
- Update to version 0.9.2
  * Add shortcut to copy URL to clipboard (primary).
  * Add option to pipe URL into external command.
* Wed Dec 12 2018 Dr. Werner Fink <werner@suse.de>
- Update to version 0.9.1
  * Add incremental search feature. (#13)
  * Other misc bug fixes/enhancements (PR #74)
  * Fix crash when URL list not visible. Closes #68
  * Fix unescape bug. Closes #67
  * Bugfix in browser handling. Fixes #70
  * Fix crash caused by webbrowser module bug.
  * PEP8 fixes/modifications
  * Update tld list
  * Fix up arrow bug. Closes #66
  * Add optional config file for editing/adding palettes.
  * Simplify palette variable to only used values. Cycle through available palettes
  * Merge branch 'runtime_palette_switch' of
    https://github.com/machinedgod/urlscan into machinedgod-runtime_palette_switch
  * Fix crash when BROWSER not set. Closes #60, Fixes #63
  * Don't handle mouse events. Fixes #65.
  * Hitting 'b' key now switches palettes
  * Allow https URLs for images
  * Add #51. Execute arbitrary expression for URL in place of opening browser.
  * More fixes for #48. Refresh screen after text browser use
  * Fix #49. Deduplication display issue.
  * Fix #50. Detect and add ability to remove escape char \ from URLs.
  * Fix #48. Prevent loading thread from affecting screen when using
  * terminal browsers.
  * Add g/G as top/bottom keyboard shortcuts. Fix #47
  * Update minimum urwid version
  * Type number to jump to URL
  * Bugfix
* Wed Dec 12 2018 Dr. Werner Fink <werner@suse.de>
- Move to python3 (boo#1119223)
* Tue Jul  4 2017 werner@suse.de
- Update to version 0.8.6
  * Fix tag mismatch in setup.py
  * Fix #27 (URLs in markdown links)
  * Tweak email address recognition
  * Add ability to toggle context view
  * Cleanup, commenting, add keyboard hints in the header
  * Add shortening and toggling shortening of URLs
  * Restructure URLChooser for current urwid best practices
  * Update tlds list
  * Replace AttrWrap (deprecated) with AttrMap
  * Highlight selected URL. Fix #17
  * Implement #21 (Option to remove duplicate URLs)
* Mon Mar 13 2017 werner@suse.de
- Reflect change in build system and/or rpmbuild now adding the package
  default documentation tree only as directory now
* Mon Feb 13 2017 werner@suse.de
- Inital package urlscan 0.8.3 which is an replacement for urlview
